@@ -4,7 +4,7 @@
 from .action import Action
 from .event import Event
 from .property import Property
-from .server import WebThingServer
+from .server import ThingTalk
 from .containers import SingleThing, MultipleThings
 from .thing import Thing
 from .value import Value
