@@ -1,6 +1,10 @@
 """Python Web Thing server implementation."""
 
 import socket
+import asyncio
+
+import zmq
+import zmq.asyncio
 
 from zeroconf import ServiceInfo, Zeroconf
 from tortoise import Tortoise
@@ -30,6 +34,8 @@ from .mixins import AsyncMixin
 from .db import init
 from .thing import Server
 
+context = zmq.asyncio.Context()
+
 
 class DefaultHeaderMiddleware(BaseHTTPMiddleware):
     """Set the default headers for all requests."""
@@ -53,20 +59,20 @@ middlewares = [
 ]
 
 
-class WebThingServer(AsyncMixin):
+class ThingTalk(AsyncMixin):
     """Server to represent a Web Thing over HTTP."""
 
     def __init__(
-        self,
-        loop,
-        thing_cls=None,
-        port=8000,
-        hostname=None,
-        base_path="",
-        additional_routes=None,
-        additional_middlewares=None,
-        additional_on_startup=None,
-        additional_on_shutdown=None,
+            self,
+            loop,
+            thing_cls=None,
+            port=8000,
+            hostname=None,
+            base_path="",
+            additional_routes=None,
+            additional_middlewares=None,
+            additional_on_startup=None,
+            additional_on_shutdown=None,
     ):
         """
         Initialize the WebThingServer.
@@ -180,7 +186,7 @@ class WebThingServer(AsyncMixin):
         return middlewares
 
     async def config_on_startups(self):
-        on_startups = [init, self.start]
+        on_startups = [init, self.start, self.zmq_sub, ]
         if self.additional_on_startup:
             on_startups.extend(self.additional_on_startup)
 
@@ -216,7 +222,8 @@ class WebThingServer(AsyncMixin):
             if middleware.cls == AuthenticationMiddleware:
                 require_auth = True
 
-        app.state.require_auth = require_auth
+        # app.state.require_auth = require_auth
+        app.state.require_auth = True
 
         return app
 
@@ -243,3 +250,20 @@ class WebThingServer(AsyncMixin):
         """Stop listening."""
         self.zeroconf.unregister_service(self.service_info)
         self.zeroconf.close()
+
+    async def zmq_sub(self):
+        asyncio.create_task(inner())
+
+
+async def inner():
+    socket = context.socket(zmq.SUB)
+    # We can connect to several endpoints if we desire, and receive from all.
+    socket.connect('tcp://127.0.0.1:2000')
+    socket.setsockopt(zmq.SUBSCRIBE, b'topic\0')
+    try:
+        while True:
+            print("begin recv json from zmq")
+            print(await socket.recv_json())
+    except asyncio.CancelledError:
+        print("cancel zmq sub")
+
